@@ -55,6 +55,8 @@ define([
      * API 모드로 이동 - API Browser open
      */
     var openAPIBrowser = function() {
+        $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIBlock")).removeClass("vp-on-btn");
+        $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIList")).addClass("vp-on-btn");
         $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).children("div").hide();
         $(vpCommon.wrapSelector(vpConst.PAGE_API_BROWSER)).show();
         $(vpCommon.wrapSelector(vpConst.PAGE_API_BROWSER))
@@ -101,21 +103,53 @@ define([
 
         // 하위 그룹 바인딩
         $(node).children(vpConst.LIBRARY_ITEM_TAG + "[" + vpConst.LIBRARY_ITEM_TYPE_ATTR + "=" + vpConst.LIBRARY_ITEM_TYPE_PACKAGE + "]").each(function() {
-            sbNaviItems.appendLine(makeNavigatorGroupTag($(this)));
-            
-            sbNaviItems.appendLine(bindNavigatorButtons($(this)));
+            // sbNaviItems.appendLine(makeNavigatorGroupTag($(this)));
+            sbNaviItems.appendLine(makeNavigatorGroupTag2($(this)));
             
             // 하위 함수 바인딩
             $(this).children(vpConst.LIBRARY_ITEM_TAG + "[" + vpConst.LIBRARY_ITEM_TYPE_ATTR + "=" + vpConst.LIBRARY_ITEM_TYPE_FUNCTION + "]").each(function() {
-                sbNaviItems.appendLine(makeNavigatorFunctionButton($(this)));
+                sbNaviItems.appendLine(makeNavigatorFunctionButton2($(this)));
             });
             
+            sbNaviItems.appendLine(bindNavigatorButtons($(this)));
+
             sbNaviItems.appendLine("</div>");
         });
         
         return sbNaviItems.toString();
     }
 
+    /**
+     * create navigator group button
+     * @param {xmlNode} node library item for create button
+     * @returns html tag string
+     */
+    var makeNavigatorGroupTag2 = function(node) {
+        var sbGrpNode = new sb.StringBuilder();
+        sbGrpNode.appendFormatLine("<div class='{0}' {1}>"
+            , vpConst.API_GROUP_BOX.replace(".", ""), ($(node).attr("level") == 0) ? "" : "style='display:none;'");
+        sbGrpNode.appendFormatLine("<span class='{0} {1}'>{2}</span>"
+            , vpConst.NAVI_GROUP_SPAN.replace(".", ""), vpConst.NAVI_GROUP_HIDDEN.replace(".", "")
+            , $(node).attr(vpConst.LIBRARY_ITEM_NAME_ATTR));
+
+        return sbGrpNode.toString();
+    }
+
+    /**
+     * create navigator group button
+     * @param {xmlNode} node library item for create button
+     * @returns html tag string
+     */
+    var makeNavigatorFunctionButton2 = function(node) {
+        var sbFuncNode = new sb.StringBuilder();
+        sbFuncNode.appendFormat("<span class='{0}' {1}='{2}' title='{3}' style='display:none;'>{4}</span>"
+            , vpConst.NAVI_FUNCTION_SPAN.replace(".", ""), vpConst.LIBRARY_ITEM_DATA_ID
+            , $(node).attr(vpConst.LIBRARY_ITEM_ID_ATTR), $(node).attr(vpConst.LIBRARY_ITEM_NAME_ATTR)
+            , $(node).attr(vpConst.LIBRARY_ITEM_NAME_ATTR));
+
+        return sbFuncNode.toString();
+    }
+
     /**
      * create navigator group button
      * @param {xmlNode} node library item for create button
@@ -154,29 +188,27 @@ define([
      * @param {HTMLtag} btn 
      */
     var toggleNaviGroupShow = function(btn) {
-        if ($(btn).hasClass(vpConst.ARROW_BTN_RIGHT)) {
-            $(btn).parent().parent().children().show();
-            $(btn).toggleClass(vpConst.ARROW_BTN_RIGHT).toggleClass(vpConst.ARROW_BTN_DOWN);
+        console.log($(this).hasClass(vpConst.NAVI_GROUP_HIDDEN));
+        if ($(btn).hasClass(vpConst.NAVI_GROUP_HIDDEN)) {
+            $(btn).parent().children().show();
+            $(btn).toggleClass(vpConst.NAVI_GROUP_HIDDEN).toggleClass(vpConst.NAVI_GROUP_SHOW);
         } else {
-            $(btn).parent().parent().children(":gt(0)").hide();
-            $(btn).toggleClass(vpConst.ARROW_BTN_RIGHT).toggleClass(vpConst.ARROW_BTN_DOWN);
+            $(btn).parent().children(":gt(0)").hide();
+            $(btn).toggleClass(vpConst.NAVI_GROUP_HIDDEN).toggleClass(vpConst.NAVI_GROUP_SHOW);
         }
+        // if ($(btn).hasClass(vpConst.ARROW_BTN_RIGHT)) {
+        //     $(btn).parent().parent().children().show();
+        //     $(btn).toggleClass(vpConst.ARROW_BTN_RIGHT).toggleClass(vpConst.ARROW_BTN_DOWN);
+        // } else {
+        //     $(btn).parent().parent().children(":gt(0)").hide();
+        //     $(btn).toggleClass(vpConst.ARROW_BTN_RIGHT).toggleClass(vpConst.ARROW_BTN_DOWN);
+        // }
     }
 
     /**
      * 노드 에디터 모드 오픈
      */
     var openAPIBlock = function() {
-        // $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).children("div").hide();
-        // $(vpCommon.wrapSelector(vpConst.NODE_EDIT_PALETTE)).show();
-        // $(vpCommon.wrapSelector(vpConst.OPTION_CONTAINER)).show();
-        // $(vpCommon.wrapSelector(vpConst.OPTION_CONTROL_PANEL)).show();
-        // $(vpCommon.wrapSelector(vpConst.NODE_EDIT_PALETTE))
-        //     .css('height', ($(vpCommon.getVPContainer()).height() - $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).position().top) / 2);
-        // $(vpCommon.wrapSelector(vpConst.OPTION_CONTAINER))
-        //     .css('height', $(vpCommon.getVPContainer()).height() - $(vpCommon.wrapSelector(vpConst.OPTION_CONTAINER)).position().top
-        //     - $(vpCommon.wrapSelector(vpConst.OPTION_CONTROL_PANEL)).height());
-        // //FIXME:
         loadOption("api_block", optionPageLoadCallback);
     }
 
@@ -248,6 +280,19 @@ define([
      * 옵션 페이지 html 처리 및 헤더 바인딩
      */
     var makeUpGreenRoomHTML = function() {
+        var headerTitle = "";
+        
+        if (loadedFuncID == "api_block") {
+            headerTitle = vpConst.VP_PAGE_HEADER_API_BLOCK;
+            $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIList")).removeClass("vp-on-btn");
+            $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIBlock")).addClass("vp-on-btn");
+        } else {
+            headerTitle = vpConst.VP_PAGE_HEADER_API_LIST;
+            $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIBlock")).removeClass("vp-on-btn");
+            $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openAPIList")).addClass("vp-on-btn");
+        }
+        
+        $(vpCommon.wrapSelector(vpConst.OPTION_CONTAINER, vpConst.VP_PAGE_HEADER)).html(headerTitle);
         $(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM, vpConst.OPTION_PAGE)).each(function() {
             $(vpCommon.wrapSelector(vpConst.OPTION_CONTAINER)).append($(this));
         });
@@ -295,6 +340,7 @@ define([
     var clearNoteArea = function() {
         $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER, vpConst.NOTE_NODE_CLASS)).remove();
         nodeIndex = 0;
+        $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openVPNote")).removeClass("vp-on-btn");
     }
 
     /**
@@ -305,7 +351,7 @@ define([
         $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).show();
         $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER))
             .css('height', $(vpCommon.getVPContainer()).height() - $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).position().top);
-        console.log($(vpCommon.getVPContainer()).width() / 3);
+        
         if ($(vpCommon.getVPContainer()).width() / 3 > 200) {
             $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).css('width', $(vpCommon.getVPContainer()).width() / 3 * 2);
             $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).css('width', $(vpCommon.getVPContainer()).width() / 3);
@@ -313,6 +359,7 @@ define([
             $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).css('width', $(vpCommon.getVPContainer()).width() - 200);
             $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).css('width', 200);
         }
+        $(vpCommon.wrapSelector(vpConst.VP_ID_PREFIX + "openVPNote")).addClass("vp-on-btn");
     }
 
     /**
@@ -343,7 +390,6 @@ define([
         sbNoteNode.appendLine("</div>");
 
         $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).append(sbNoteNode.toString());
-        console.log(JSON.parse($(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).find(vpConst.NOTE_NODE_GENE_META).val()));
     }
 
     /**
@@ -352,7 +398,6 @@ define([
      */
     var loadNoteNodeOption = function(btn) {
         generatedMetaData = JSON.parse($(btn).parent().parent().children(vpConst.NOTE_NODE_GENE_META).val());
-        console.log(generatedMetaData.funcID);
         loadOption(generatedMetaData.funcID, optionPageLoadCallbackAndLoad);
     }
 
@@ -427,7 +472,6 @@ define([
     var saveNoteFile = function() {
         var noteClone = $(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).clone();
         $(noteClone).children().not(vpConst.NOTE_NODE_CLASS).remove();
-        console.log($(noteClone).html());
         
         var sbNoteData = new sb.StringBuilder();
         sbNoteData.appendFormatLine("%%writefile {0}", $(vpCommon.wrapSelector('#noteFilePath')).val());
@@ -450,7 +494,9 @@ define([
     var calculateDivisionSize = function() {
         $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER))
             .css('height', $(vpCommon.getVPContainer()).height() - $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).position().top);
-
+        $(vpCommon.wrapSelector(vpConst.VP_HEADER_BUTTONS))
+            .css('width', $(vpCommon.getVPContainer()).width() - $(vpCommon.wrapSelector(vpConst.VP_HEADER_TEXT)).width() - 14);
+        
         if ($(vpCommon.wrapSelector(vpConst.VP_NOTE_CONTAINER)).is(":visible")) {
             if ($(vpCommon.getVPContainer()).width() / 3 > 200) {
                 $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).css('width', $(vpCommon.getVPContainer()).width() / 3 * 2);
@@ -462,9 +508,6 @@ define([
         } else {
             $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).css('width', $(vpCommon.getVPContainer()).width());
         }
-        // var subContainerHeight = $(vpCommon.getVPContainer()).height() - 85;
-        // $(vpCommon.wrapSelector(vpConst.VP_BODY_CONTAINER)).children("div").attr("height", subContainerHeight);
-        // console.log(subContainerHeight);
     }
 
     /**
@@ -516,14 +559,21 @@ define([
     /**
      * api browser 
      */
-    $(document).on("click", vpCommon.wrapSelector(vpConst.API_GROUP_BOX, vpConst.NAVI_GROUP_TOGGLE), function() {
+    $(document).on("click", vpCommon.wrapSelector(vpConst.API_GROUP_BOX, ".vp-span-group"), function() {
         toggleNaviGroupShow($(this));
     });
 
     /**
      * navi 함수 클릭(옵션 로드)
      */
-    $(document).on("click", vpCommon.wrapSelector(vpConst.NAVI_FUNCION_BUTTON), function() {
+    // $(document).on("click", vpCommon.wrapSelector(vpConst.NAVI_FUNCION_BUTTON), function() {
+    //     loadOption($(this).data(vpConst.LIBRARY_ITEM_DATA_ID.replace(vpConst.TAG_DATA_PREFIX, "")), optionPageLoadCallback);
+    // });
+
+    /**
+     * navi 함수 클릭(옵션 로드)
+     */
+    $(document).on("click", vpCommon.wrapSelector(vpConst.NAVI_FUNCTION_SPAN), function() {
         loadOption($(this).data(vpConst.LIBRARY_ITEM_DATA_ID.replace(vpConst.TAG_DATA_PREFIX, "")), optionPageLoadCallback);
     });
 
@@ -595,7 +645,7 @@ define([
             },
             returnVariable:"",    // 반환값
             isReturnVariable: false,
-            fileExtension: "vp" // 확장자
+            fileExtension: vpConst.VPNOTE_EXTENSION // 확장자
         }; 
         this.fileResultState = {
             pathInputId : vpCommon.wrapSelector('#noteFilePath')
@@ -684,16 +734,22 @@ define([
     /**
      * 노트 파일 로드
      */
-    $(document).on("fileReadSelected.fileNavigation", function() {
-        loadNoteFile();
-    })
+    $(document).on("fileReadSelected.fileNavigation", function(e) {
+        // 선택 파일 확장자가 노트 세이브 파일인 경우만 동작
+        if (e.path.substring(e.path.lastIndexOf(".") + 1) === vpConst.VPNOTE_EXTENSION) {
+            loadNoteFile();
+        }
+    });
     
     /**
      * 노트 파일 세이브
      */
-    $(document).on("fileSaveSelected.fileNavigation", function() {
-        saveNoteFile();
-    })
+    $(document).on("fileSaveSelected.fileNavigation", function(e) {
+        // 선택 파일 확장자가 노트 세이브 파일인 경우만 동작
+        if (e.path.substring(e.path.lastIndexOf(".") + 1) === vpConst.VPNOTE_EXTENSION) {
+            saveNoteFile();
+        }
+    });
 
     /**
      * 컨테이너 사이즈 변경시 division resize
@@ -707,7 +763,7 @@ define([
      */
     events.on('select.Cell', function (event, data) {
         var index = Jupyter.notebook.find_cell_index(data.cell);
-        console.log(index);
+        // console.log(index);
     });
 
     /**
