@@ -10,10 +10,10 @@ define ([
      
         var rootTagSelector = numpyPageRendererThis.getRootTagSelector();
         var optionPage = $(numpyPageRendererThis.importPackageThis.wrapSelector(rootTagSelector));
-        var additionalOptionDomElement = $(`<div class="vp-numpy-optionPageBlock-view vp-numpy-block vp-minimize">
+        var additionalOptionDomElement = $(`<div class='vp-numpy-optionPageBlock-view vp-numpy-block vp-minimize'>
                                                 <h4>
-                                                    <div class="vp-panel-area-vertical-btn vp-arrow-down"></div>
-                                                    <span class="vp-multilang" data-caption-id="TODO:Variable">
+                                                    <div class='vp-panel-area-vertical-btn vp-arrow-down'></div>
+                                                    <span class='vp-multilang' data-caption-id='TODO:Variable'>
                                                         Additional Options
                                                     </span>
                                                 </h4>
