@@ -10,11 +10,11 @@ define ([
      
         var rootTagSelector = numpyPageRendererThis.getRootTagSelector();
         var optionPage = $(numpyPageRendererThis.importPackageThis.wrapSelector(rootTagSelector));
-        var additionalOptionDomElement = $(`<div class="vp-numpy-requiredPageBlock-view 
-                                                        vp-numpy-block ">
+        var additionalOptionDomElement = $(`<div class='vp-numpy-requiredPageBlock-view 
+                                                        vp-numpy-block '>
                                                 <h4>
-                                                    <div class="vp-panel-area-vertical-btn vp-arrow-up"></div>
-                                                    <span class="vp-multilang" data-caption-id="TODO:Variable">
+                                                    <div class='vp-panel-area-vertical-btn vp-arrow-up'></div>
+                                                    <span class='vp-multilang' data-caption-id='TODO:Variable'>
                                                         Required Input &amp; Output
                                                     </span>
                                                 </h4>
