@@ -10,9 +10,8 @@ define([
               componentConstApi, fileNavigationExecutorFuncList) {
     
     // kernel executor에 필요한 함수 import
-    var { executeKernelFromDir
-          , executeKernelFromDirLeftTab
-          , executeKernelFromDirRightBody } = fileNavigationExecutorFuncList;
+    var { executeKernelFromDir,
+          executeKernelFromDirRightBody } = fileNavigationExecutorFuncList;
     // dom 만드는데 필요한 함수 import
     var { makeDom, controlToggleInput, closeComponent } = componentConstApi;
     // stringBuilder import
@@ -54,8 +53,6 @@ define([
             $('.directoryComponent-savebutton').append(saveFileDataInput);
             $('.directoryComponent-savebutton').append(saveFileDataBtn);
          
-            // $(`.directoryComponent-menu`).append(saveFileDataBtn);
-            // $(`.directoryComponent-menu`).append(saveFileDataInput);
             controlToggleInput();
             $(saveFileDataInput).on('change keyup paste', function() {
                 fileNavigationState.setVisualPythonFileName($(this).val());
@@ -274,7 +271,6 @@ define([
         fileNavigationRendererThis.fileNavigationState.setCurrentDirStr(currentDirStr);
 
         $('.directoryComponent-container').find('#vp_loadingBar').remove();
-        // $('.directoryComponent-directory-nowLocation').html(`/${currentRelativePathStr}`);
     }
 
     // 로딩을 생성하는 함수
@@ -289,7 +285,7 @@ define([
         var fileNavigationState = this.getFileNavigationState();
         fileNavigationState.setRelativePathStr(currentRelativePathStr);
         fileNavigationState.setCurrentDirStr(currentDirStr);
-        var notebookPathStr = fileNavigationState.getBaseFolderStr();
+
         var notebookPathStr = fileNavigationState.getNotebookPathStr();
         var notebookPathStrLength = notebookPathStr.length;
         var baseFolder = fileNavigationState.getBaseFolderStr();
@@ -348,7 +344,7 @@ define([
         var fileNavigationRendererThis = this;
         var fileNavigationState = fileNavigationRendererThis.getFileNavigationState();
 
-        /** 상대 경로 string을 자르고 붙이는 로직 300 라인 부터 344 라인까지 */
+        /** 상대 경로 string을 자르고 붙이는 로직 */
         var baseFolder = fileNavigationState.getBaseFolderStr();
         var baseDirStr = fileNavigationState.getBaseDirStr();
         var noteBookPathStr = fileNavigationState.getNotebookPathStr();
@@ -419,11 +415,17 @@ define([
         vpCommon.renderSuccessMessage(`${filePathStr} 파일 선택 완료되었습니다`);
         /** 장안태 추가. 파일 선택 완료시 문서 이벤트 발동 */
         if (fileNavigationState.getFileNavigationtype() === 'SAVE_FILE') {
-            $(document).trigger("fileSaveSelected.fileNavigation");
+            $(document).trigger({
+                type:"fileSaveSelected.fileNavigation",
+                path:`${filePathStr}`
+            });
         } else {
-            $(document).trigger("fileReadSelected.fileNavigation");
+            $(document).trigger({
+                type:"fileReadSelected.fileNavigation",
+                path:`${filePathStr}`
+            });
         }
-        // $('.FileNavigationPage-inner').find('#vp_yesOrNoModal').remove();
+   
         $('#vp_fileNavigation').addClass('hide');
         $('#vp_fileNavigation').removeClass('show');
         $('#vp_fileNavigation').remove();
