@@ -12,7 +12,8 @@ define([
     const funcOptProp = {
         stepCount : 1
         , funcName : "Plot"
-        , funcID : "pd121"  // TODO: ID 규칙 생성 필요
+        , funcID : "pd_plot"  // TODO: ID 규칙 생성 필요
+        , libID : "pd121"
     }
 
     /**
@@ -59,7 +60,7 @@ define([
     var PandasPackage = function(uuid) {
         this.uuid = uuid;   // Load html 영역의 uuid.
         // pandas 함수
-        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.funcID];
+        this.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
         // plot 종류
         this.plotKind = {
             'line': '선',
@@ -174,7 +175,7 @@ define([
                     $(that.wrapSelector('#y')).closest('tr').find('label').text("* " + that.package.variable[idy].label);
                 }
             } else {
-                that.package = libPandas._PANDAS_FUNCTION[funcOptProp.funcID];
+                that.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
 
                 // 라벨 재정비
                 var idx = that.package.variable.findIndex(function(item) {return item.name === 'x'});
